@@ -48,7 +48,7 @@ def send_raven(**kwargs):
             ]
         )
 
-    if kwargs["attachment"]:
+    if "attachment" in kwargs:
         file_bytes_b64 = base64.b64encode(bytes(kwargs["attachment"]["data"], 'utf-8'))
 
         attachment = EmailAttachment(
